@@ -66,6 +66,9 @@ class CategoryManager(Manager):
         categories = []
         sub_categories = []
         for cat in cat_items:
+            # grab only those categories that have associated objects
+            if not cat.object or not hasattr(cat.object, 'status') or not cat.object.status:
+                continue
             if cat.category and cat.category not in categories:
                 categories.append(cat.category)
             elif cat.parent and cat.parent not in sub_categories:
