@@ -60,7 +60,10 @@ class Email(TendenciBaseModel):
 
         email_to_test = email_to_test.lower()
         email_domain = email_to_test.split('@')[1]
-        return EmailBlock.objects.filter(Q(email=email_to_test) | Q(email_domain=email_domain)
+        email_domain_p2 = email_domain.split('.')[-1]
+        return EmailBlock.objects.filter(Q(email=email_to_test) 
+                                         | Q(email_domain=email_domain)
+                                         | Q(email_domain=email_domain_p2)
                                          ).exists()
 
     def send(self, fail_silently=False, **kwargs):
@@ -112,7 +115,7 @@ class Email(TendenciBaseModel):
                 recipient_bcc_list.remove(e)
 
         if recipient_list or recipient_bcc_list:
-            msg = EmailMessage(self.subject,
+            msg = EmailMessage(self.clean_subject(self.subject),
                                add_tendenci_footer(self.body, content_type=self.content_type),
                                self.sender,
                                recipient_list,
@@ -126,6 +129,9 @@ class Email(TendenciBaseModel):
                     msg.attach(name, value)
             msg.send(fail_silently=fail_silently)
 
+    def clean_subject(self, subject):
+        return subject.replace('\r', ' ').replace('\n', ' ').strip()
+
     def save(self, user=None, *args, **kwargs):
         if not self.id:
             self.guid = uuid.uuid4()
