@@ -1,12 +1,17 @@
+from re import RegexFlag
+from os import path
 from django.db import models
 from django.urls import reverse
+from django.core import validators
 from django.utils.translation import gettext, gettext_lazy as _
 from django.contrib.auth.models import User
 from django.contrib.contenttypes.fields import GenericRelation
 from django.utils.safestring import mark_safe
 from django.contrib.contenttypes.models import ContentType
+from django.template.defaultfilters import truncatewords
 
 from django_countries import countries as COUNTRIES
+
 from localflavor.us.us_states import STATE_CHOICES, US_STATES
 from localflavor.ca.ca_provinces import PROVINCE_CHOICES
 
@@ -16,13 +21,13 @@ from tendenci.apps.perms.models import TendenciBaseModel
 from tendenci.apps.perms.object_perms import ObjectPermission
 from tendenci.apps.user_groups.models import Group, GroupMembership
 from tendenci.apps.site_settings.utils import get_setting
-from tendenci.apps.base.utils import checklist_update
+from tendenci.apps.base.utils import checklist_update, tcurrency
 from tendenci.libs.abstracts.models import OrderingBaseModel
 from tendenci.apps.user_groups.utils import get_default_group
 from tendenci.apps.invoices.models import Invoice
 
-#STATUS_DRAFT = 1
-#STATUS_PUBLISHED = 2
+# STATUS_DRAFT = 1
+# STATUS_PUBLISHED = 2
 STATUS_CHOICES = (
     ('draft', _("Draft")),
     ('published', _("Published")),
@@ -181,12 +186,14 @@ class Form(TendenciBaseModel):
     def admin_link_view(self):
         url = self.get_absolute_url()
         return "<a href='%s'>%s</a>" % (url, gettext("View on site"))
+
     admin_link_view.short_description = ""
 
     @mark_safe
     def admin_link_export(self):
         url = reverse("admin:forms_form_export", args=(self.id,))
         return "<a href='%s'>%s</a>" % (url, gettext("Export entries"))
+
     admin_link_export.short_description = ""
 
     def has_files(self):
@@ -200,12 +207,14 @@ class FieldManager(models.Manager):
     """
     Only show visible fields when displaying actual form..
     """
+
     def visible(self):
         return self.filter(visible=True)
 
     """
     Get all Auto-fields. (As of writing, this is only GroupSubscriptionAuto)
     """
+
     def auto_fields(self):
         return self.filter(visible=False, field_function="GroupSubscriptionAuto")
 
@@ -231,17 +240,24 @@ class Field(OrderingBaseModel):
         choices=FIELD_FUNCTIONS, max_length=64, null=True, blank=True)
     required = models.BooleanField(_("Required"), default=True)
     visible = models.BooleanField(_("Visible"), default=True)
+    remember = models.BooleanField(_("Remember"), default=False,
+        help_text=_("Remember the value entered between visits and initialise the form with that value."))
     choices = models.CharField(_("Choices"), max_length=1000, blank=True,
         help_text=_("Comma separated options where applicable"))
     default = models.CharField(_("Default"), max_length=1000, blank=True,
         help_text=_("Default value of the field"))
+    summary_position = models.CharField(_("Summary Position"), max_length=6, blank=True,
+        help_text=_("Position in the one line form entry summary. Row, Position or just Position.\nSome examples:\n2,1   for row 2, position 1\n2      for row 1, positon 2."),
+        validators=[validators.RegexValidator(r"^\s*\d+(\s*,\s*\d+)?(\s*,\s*(b|f|\$|w\d+))?$",
+                                              "Summary position must have 1 to 3 comma separated values:\nrow,column,format\nrow is optional and assumed to be 1 if missing, supported formats are: $ for numbers, b for boolean, f for filename and wn for first n words.",
+                                              flags=RegexFlag.IGNORECASE)])
 
     objects = FieldManager()
 
     class Meta:
         verbose_name = _("Field")
         verbose_name_plural = _("Fields")
-        #order_with_respect_to = "form"
+        # order_with_respect_to = "form"
         app_label = 'forms'
 
     def __str__(self):
@@ -264,21 +280,21 @@ class Field(OrderingBaseModel):
     def get_choices(self):
         if self.field_type == 'CountryField':
             exclude_list = ['GB', 'US', 'CA']
-            countries = ((name,name) for key,name in COUNTRIES if key not in exclude_list)
+            countries = ((name, name) for key, name in COUNTRIES if key not in exclude_list)
             initial_choices = ((_('United States'), _('United States')),
                                (_('Canada'), _('Canada')),
                                (_('United Kingdom'), _('United Kingdom')),
-                               ('','-----------'))
+                               ('', '-----------'))
             choices = initial_choices + tuple(countries)
         elif self.field_type == 'StateProvinceField':
             if get_setting('site', 'global', 'usstatesonly'):
                 choices = (('', '-----------'),) + tuple((state, state_f.title()) for state, state_f in US_STATES)
             else:
-                choices = (('','-----------'),) + tuple((state, state_f.title()) for state, state_f in STATE_CHOICES) \
-                                    + tuple((prov, prov_f.title()) for prov, prov_f in PROVINCE_CHOICES)
+                choices = (('', '-----------'),) + tuple((state, state_f.title()) for state, state_f in STATE_CHOICES) \
+                                    +tuple((prov, prov_f.title()) for prov, prov_f in PROVINCE_CHOICES)
                 choices = sorted(choices)
         elif self.field_function == 'Recipients':
-            choices = [(label+':'+val, label) for label, val in (i.split(":") for i in self.choices.split(","))]
+            choices = [(label + ':' + val, label) for label, val in (i.split(":") for i in self.choices.split(","))]
         else:
             choices = [(val, val) for val in self.choices.split(",")]
         return choices
@@ -312,7 +328,7 @@ class FormEntry(models.Model):
     payment_method = models.ForeignKey('payments.PaymentMethod', null=True, on_delete=models.SET_NULL)
     pricing = models.ForeignKey('Pricing', null=True, on_delete=models.SET_NULL)
     custom_price = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)
-    creator = models.ForeignKey(User, related_name="formentry_creator",  null=True, on_delete=models.SET_NULL)
+    creator = models.ForeignKey(User, related_name="formentry_creator", null=True, on_delete=models.SET_NULL)
     create_dt = models.DateTimeField(auto_now_add=True)
     update_dt = models.DateTimeField(auto_now=True)
 
@@ -324,13 +340,83 @@ class FormEntry(models.Model):
     def __str__(self):
         return ('%s submission' % (self.form.title,))
 
+    @property
+    def summary(self):
+        field_map = {}
+        for entry_field in self.entry_fields():
+            form_field = self.form.fields.get(id=entry_field.field_id)
+            vals = [p.strip() for p in form_field.summary_position.split(',')]
+
+            if not vals[-1].isnumeric() or len(vals) > 2:
+                fmt = vals.pop()
+            else:
+                fmt = ""
+
+            if len(vals) == 1:
+                row = 1
+                col = int(vals[0]) if vals[0].isnumeric() else 0
+            elif vals:
+                row = int(vals[0]) if vals[0].isnumeric() else 0
+                col = int(vals[1]) if vals[1].isnumeric() else 0
+            else:
+                row = col = 0  # Don't display this value
+
+            if row and not (row in field_map):
+                field_map[row] = {}
+
+            if row and col:
+                if fmt.startswith("$"):
+                    try:
+                        value = tcurrency(entry_field.value.strip())
+                    except:
+                        value = entry_field.value.strip()
+                elif fmt.startswith("f"):
+                    value = path.basename(entry_field.value)
+                elif fmt.startswith("b"):
+                    pfx = "NOT " if not entry_field.value else ""
+                    value = f"{pfx}{entry_field.field.label}"
+                elif fmt.startswith("w"):
+                    if fmt[1:].isnumeric():
+                        words = int(fmt[1:])
+                        value = truncatewords(entry_field.value.strip(), words)
+                else:
+                    value = entry_field.value.strip()
+
+                field_map[row][col] = value
+
+        # If no field map is provided apply legacy format
+        # entry_time followed by first 3 fields by position truncated to 2 words or basename if file field
+        if not field_map:
+            field_map[1] = {}
+            field_map[1][1] = self.entry_time.strftime("%c")
+            for i, entry_field in enumerate(self.entry_fields()[:3]):
+                if entry_field.field.field_type == 'FileField':
+                    field_map[1][i + 2] = path.basename(entry_field.value)
+                else:
+                    field_map[1][i + 2] = truncatewords(entry_field.value.strip(), 2)
+
+        # If row 1, col 1 is empty, put the entry_time there.
+        elif not field_map.get(1, {}).get(1, None):
+            if not 1 in field_map:
+                field_map[1] = {}
+            field_map[1][1] = self.entry_time.strftime("%c")
+
+        rows = []
+        for row in sorted(field_map.keys()):
+            cols = []
+            for col in sorted(field_map[row].keys()):
+                cols.append(field_map[row][col])
+            rows.append(" - ".join(cols))
+
+        return rows
+
     def get_absolute_url(self):
         return reverse('form_entry_detail', kwargs={"id": self.pk})
 
     @property
     def owner(self):
         return self.creator
-    
+
     @property
     def group(self):
         return self.form.group
@@ -431,7 +517,7 @@ class FormEntry(models.Model):
 
     def get_position_title(self):
         return self.get_value_of("position_title")
- 
+
     def get_referral_source(self):
         return self.get_value_of("referral_source")
 
@@ -480,7 +566,7 @@ class FormEntry(models.Model):
 
     def check_and_create_user(self):
         """
-        Check and create a new user if needed (only if payment is involved or 
+        Check and create a new user if needed (only if payment is involved or
             "Subscribe to Group" functionality is selected).
         Return the user created or None.
         """
@@ -493,7 +579,7 @@ class FormEntry(models.Model):
             if user_list:
                 anonymous_creator = user_list[0]
             else:
-                # Create a new user only if payment is involved or 
+                # Create a new user only if payment is involved or
                 # "Subscribe to Group" functionality selected
                 if get_setting('module', 'forms', 'form_submission_create_user') or \
                          self.form.custom_payment or self.form.recurring_payment or \
@@ -514,7 +600,7 @@ class FormEntry(models.Model):
                     anonymous_creator.set_unusable_password()
                     anonymous_creator.is_active = False
                     anonymous_creator.save()
-                    
+
                     anonymous_profile = Profile(user=anonymous_creator,
                                                 owner=anonymous_creator,
                                                 creator=anonymous_creator,
@@ -607,4 +693,4 @@ class Pricing(models.Model):
         currency_symbol = get_setting("site", "global", "currencysymbol")
         if not currency_symbol:
             currency_symbol = '$'
-        return "%s - %s%s" % (self.label, currency_symbol, self.price, )
+        return "%s - %s%s" % (self.label, currency_symbol, self.price,)
