@@ -6,7 +6,7 @@ from tendenci.apps.perms.forms import TendenciBaseForm
 
 from django.utils.safestring import mark_safe
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.template.defaultfilters import filesizeformat
 
 from tendenci.libs.tinymce.widgets import TinyMCE
