@@ -37,7 +37,7 @@ from tendenci.apps.perms.models import TendenciBaseModel
 from tendenci.apps.perms.object_perms import ObjectPermission
 from tendenci.apps.perms.utils import get_query_filters
 from tendenci.apps.base.fields import DictField
-from tendenci.apps.base.utils import apply_orientation
+from tendenci.apps.base.utils import apply_orientation, correct_filename
 from tendenci.apps.photos.managers import PhotoManager, PhotoSetManager
 from tendenci.apps.meta.models import Meta as MetaTags
 from tendenci.apps.photos.module_meta import PhotoMeta
@@ -62,6 +62,7 @@ ImageFile.MAXBLOCK = getattr(settings, 'PHOTOS_MAXBLOCK', 256 * 2 ** 10)
 
 
 def get_storage_path(instance, filename):
+    filename = correct_filename(filename)
     # AWS S3 max key length: 260 characters
     return os.path.join('photos', uuid.uuid4().hex[:8], filename)
 
@@ -188,6 +189,8 @@ class ImageModel(models.Model):
             self.create_size(photosize)
         if photosize.increment_count:
             self.increment_count()
+        if settings.USE_S3_STORAGE:
+            return default_storage.url(self._get_SIZE_filename(size))
         return '/'.join([self.cache_url(), self._get_filename_for_size(photosize.name)])
 
     def _get_SIZE_filename(self, size):
@@ -550,6 +553,24 @@ class PhotoSizeCache(object):
         self.sizes = {}
 
 
+class PhotoCategory(models.Model):
+    name = models.CharField(max_length=255)
+    slug = models.SlugField(unique=True, blank=True, null=True)
+    parent = models.ForeignKey('self', null=True, on_delete=models.CASCADE)
+
+    class Meta:
+        verbose_name = _("Photo Set Category")
+        verbose_name_plural = _("Photo Set Categories")
+        ordering = ('name',)
+        app_label = 'photos'
+
+    def __str__(self):
+        return self.name
+
+    def photo_count(self):
+        return Image.objects.filter(cat=self).count()
+
+
 class PhotoSet(OrderingBaseModel, TendenciBaseModel):
     """
     A set of photos
@@ -566,6 +587,13 @@ class PhotoSet(OrderingBaseModel, TendenciBaseModel):
     tags = TagField(blank=True, help_text=_("Tags are separated by commas, ex: Tag 1, Tag 2, Tag 3"))
     author = models.ForeignKey(User, null=True, on_delete=models.SET_NULL)
 
+    cat = models.ForeignKey(PhotoCategory, verbose_name=_("Category"),
+                                 related_name="cat_photo_sets", null=True,
+                                 on_delete=models.SET_NULL)
+    sub_cat = models.ForeignKey(PhotoCategory, verbose_name=_("Sub Category"),
+                                related_name="sub_cat_photo_sets", null=True,
+                                on_delete=models.SET_NULL)
+
     perms = GenericRelation(ObjectPermission,
                                           object_id_field="object_id",
                                           content_type_field="content_type")
@@ -606,7 +634,6 @@ class PhotoSet(OrderingBaseModel, TendenciBaseModel):
     def get_cover_photo(self, *args, **kwargs):
         """ get latest thumbnail url """
         cover_photo = None
-
         if hasattr(self, 'cover_photo'):
             return self.cover_photo
 
@@ -718,6 +745,9 @@ class Image(OrderingBaseModel, ImageModel, TendenciBaseModel):
     photographer = models.CharField(_('Photographer'),
                                     blank=True, null=True,
                                     max_length=100)
+    cat = models.ForeignKey(PhotoCategory, verbose_name=_("Category"),
+                                 related_name="cat_photos", null=True,
+                                 on_delete=models.SET_NULL)
 
     # html-meta tags
     meta = models.OneToOneField(MetaTags, blank=True, null=True, on_delete=models.SET_NULL)
@@ -759,7 +789,8 @@ class Image(OrderingBaseModel, ImageModel, TendenciBaseModel):
         #caching.instance_cache_add(self, self.pk)
 
         if not self.is_public_photo() or not self.is_public_photoset():
-            if hasattr(settings, 'USE_S3_STORAGE') and settings.USE_S3_STORAGE and hasattr(self.image, 'file'):
+            if hasattr(settings, 'USE_S3_STORAGE') and settings.USE_S3_STORAGE \
+                and self.image and default_storage.exists(self.image.name):
                 set_s3_file_permission(self.image.file, public=False)
             cache_set = cache.get("photos_cache_set.%s" % self.pk)
             if cache_set is not None:
