@@ -23,6 +23,7 @@ from django.forms.models import modelformset_factory
 from django.core.files.base import ContentFile
 from django.db.models import Q
 from django.middleware.csrf import get_token as csrf_get_token
+from django.views.decorators.csrf import csrf_exempt
 
 from tendenci.libs.utils import python_executable
 from tendenci.apps.theme.shortcuts import themed_response as render_to_resp
@@ -38,8 +39,10 @@ from tendenci.apps.user_groups.models import Group
 
 from tendenci.apps.photos.cache import PHOTO_PRE_KEY
 #from tendenci.apps.photos.search_indexes import PhotoSetIndex
-from tendenci.apps.photos.models import Image, PhotoSet, AlbumCover, License
-from tendenci.apps.photos.forms import PhotoEditForm, PhotoSetAddForm, PhotoSetEditForm, PhotoBatchEditForm
+from tendenci.apps.photos.models import Image, PhotoSet, AlbumCover, License, PhotoCategory
+from tendenci.apps.photos.forms import (
+    PhotoEditForm, PhotoSetForm, PhotoBatchEditForm,
+    PhotoForm, PhotoBaseFormSet,PhotoSetSearchForm)
 from tendenci.apps.photos.utils import get_privacy_settings
 from tendenci.apps.photos.tasks import ZipPhotoSetTask
 from tendenci.apps.base.utils import apply_orientation
@@ -68,6 +71,23 @@ def search(request, template_name="photos/search.html"):
         context={"photos": photos})
 
 
+@is_enabled('photos')
+def category_photos(request, slug, template_name="photos/category_photos.html"):
+    cat = get_object_or_404(PhotoCategory, slug=slug)
+    filters = get_query_filters(request.user, 'photos.view_image')
+    photos = Image.objects.filter(cat=cat).filter(filters).distinct()
+    if not request.user.is_anonymous:
+        photos = photos.select_related()
+
+    photos = photos.order_by('-create_dt')
+
+    EventLog.objects.log()
+
+    return render_to_resp(request=request, template_name=template_name,
+        context={"photos": photos,
+                 'cat': cat})
+
+
 @is_enabled('photos')
 def sizes(request, id, size_name='', template_name="photos/sizes.html"):
     """ Show all photo sizes """
@@ -235,7 +255,7 @@ def photo_size(request, id, size, crop=False, quality=90, download=False, constr
     file_name = photo.image_filename()
     file_path = 'cached%s%s' % (request.path, file_name)
     if default_storage.exists(file_path):
-        image = get_image_from_path(os.path.join(settings.MEDIA_ROOT, file_path))
+        image = PILImage.open(default_storage.open(file_path))
     else:
         # gets resized image from cache or rebuild
         image = get_image(photo.image, size, PHOTO_PRE_KEY, crop=crop, quality=quality, unique_key=str(photo.pk), constrain=constrain)
@@ -404,7 +424,7 @@ def delete(request, id, set_id=0):
 
 @is_enabled('photos')
 @login_required
-def photoset_add(request, form_class=PhotoSetAddForm, template_name="photos/photo-set/add.html"):
+def photoset_add(request, form_class=PhotoSetForm, template_name="photos/photo-set/add.html"):
     """ Add a photo set """
     # if no permission; permission exception
     if not has_perm(request.user,'photos.add_photoset'):
@@ -435,7 +455,7 @@ def photoset_add(request, form_class=PhotoSetAddForm, template_name="photos/phot
 
 @is_enabled('photos')
 @login_required
-def photoset_edit(request, id, form_class=PhotoSetEditForm, template_name="photos/photo-set/edit.html"):
+def photoset_edit(request, id, form_class=PhotoSetForm, template_name="photos/photo-set/edit.html"):
     from tendenci.apps.perms.object_perms import ObjectPermission
     photo_set = get_object_or_404(PhotoSet, id=id)
 
@@ -504,23 +524,42 @@ def photoset_delete(request, id, template_name="photos/photo-set/delete.html"):
 @is_enabled('photos')
 def photoset_view_latest(request, template_name="photos/photo-set/latest.html"):
     """ View latest photo set """
-    query = request.GET.get('q', None)
-    filters = get_query_filters(request.user, 'photos.view_photoset')
-    photo_sets = PhotoSet.objects.filter(filters).distinct()
-    if not request.user.is_anonymous:
-        photo_sets = photo_sets.select_related()
+    form = PhotoSetSearchForm(request.GET)
+    if form.is_valid():
+        filters = get_query_filters(request.user, 'photos.view_photoset')
+        photo_sets = PhotoSet.objects.filter(filters).distinct()
+        query = form.cleaned_data.get('q')
+        cat = form.cleaned_data.get('cat', '')
+        sub_cat = form.cleaned_data.get('sub_cat', '')
+        if cat:
+            photo_sets = photo_sets.filter(cat=cat)
+        if sub_cat:
+            photo_sets = photo_sets.filter(sub_cat=sub_cat)
+        if query:
+            photo_sets = photo_sets.filter(Q(name__icontains=query)|
+                                           Q(description__icontains=query)|
+                                           Q(tags__icontains=query))
 
-    if query:
-        photo_sets = photo_sets.filter(Q(name__icontains=query)|
-                                       Q(description__icontains=query)|
-                                       Q(tags__icontains=query))
+        if not request.user.is_anonymous:
+            photo_sets = photo_sets.select_related()
 
-    photo_sets = photo_sets.order_by('position', '-create_dt')
+        photo_sets = photo_sets.order_by('position', '-create_dt')
+    else:
+        # invalid form
+        photo_sets = PhotoSet.objects.none()
+        cat = None
+
+    if cat:
+        photo_cats = PhotoCategory.objects.filter(parent=cat)
+    else:
+        photo_cats = None
 
     EventLog.objects.log()
 
     return render_to_resp(request=request, template_name=template_name,
-        context={"photo_sets": photo_sets})
+        context={"photo_sets": photo_sets,
+                 'form': form,
+                 'photo_cats': photo_cats})
 
 
 @is_enabled('photos')
@@ -533,6 +572,24 @@ def photoset_view_yours(request, template_name="photos/photo-set/yours.html"):
     })
 
 
+@csrf_exempt
+def get_sub_categories(request):
+    if request.is_ajax() and request.method == "POST":
+        cat = request.POST.get('cat', None)
+        if cat:
+            sub_cats = PhotoCategory.objects.filter(parent=cat)
+            count = sub_cats.count()
+            sub_cats = list(sub_cats.values_list('pk','name'))
+            data = json.dumps({"error": False,
+                               "sub_cats": sub_cats,
+                               "count": count})
+        else:
+            data = json.dumps({"error": True})
+
+        return HttpResponse(data, content_type="text/plain")
+    raise Http404
+
+
 def handle_uploaded_photo(request, photoset_id, file_path):
     import uuid
     from django.core.files import File
@@ -661,6 +718,8 @@ def photos_batch_edit(request, photoset_id=0, template_name="photos/batch-edit.h
 
     PhotoFormSet = modelformset_factory(
         Image,
+        form=PhotoForm,
+        formset=PhotoBaseFormSet,
         exclude=(
             'title_slug',
             'creator_username',
@@ -717,7 +776,7 @@ def photos_batch_edit(request, photoset_id=0, template_name="photos/batch-edit.h
         # i would like to use the search index here; but it appears that
         # the formset class only accepts a queryset; not a searchqueryset or list
         photo_qs = Image.objects.filter(photoset=photo_set).order_by("position")
-        photo_formset = PhotoFormSet(queryset=photo_qs)
+        photo_formset = PhotoFormSet(photo_set=photo_set, queryset=photo_qs)
 
     cc_licenses = License.objects.all()
 
