@@ -317,6 +317,11 @@ class Profile(Person):
         if has_perm(user2_compare, 'profiles.view_profile'):
             return True
 
+        # chapter leaders can view
+        chapter_membership = self.chapter_membership
+        if chapter_membership and chapter_membership.chapter.is_chapter_leader(user2_compare):
+            return True
+
         # False for everythin else
         return False
 
@@ -338,6 +343,11 @@ class Profile(Person):
         if user2_compare.has_perm('profiles.change_profile', self):
             return True
 
+        # chapter leaders can edit
+        chapter_membership = self.chapter_membership
+        if chapter_membership and chapter_membership.chapter.is_chapter_leader(user2_compare):
+            return True
+
         return False
 
     def can_renew(self):
@@ -392,6 +402,12 @@ class Profile(Person):
                     status_detail='archive').order_by('-create_dt')[:1] or [None]
         return membership
 
+    @property
+    def chapter_membership(self):
+        [chapter_membership] = self.user.chaptermembership_set.exclude(
+                    status_detail='archive').order_by('-create_dt')[:1] or [None]
+        return chapter_membership
+
     def refresh_member_number(self):
         """
         Adds or removes member number from profile.
@@ -562,6 +578,9 @@ class Profile(Person):
                 default = '%s%s'%(site_url,
                                 static(settings.GAVATAR_DEFAULT_URL))
 
+        if get_setting('module', 'users', 'disablegravatar'):
+            return default or static(settings.GAVATAR_DEFAULT_URL)
+
         gravatar_url = "//www.gravatar.com/avatar/" + self.getMD5() + "?"
         gravatar_url += urlencode({'d':default, 's':str(size)})
         return gravatar_url
@@ -579,21 +598,23 @@ class Profile(Person):
 
         head, tail = os.path.split(self.photo.name)
         size_path = head + '/sizes/' + str(size) + '/' + tail
-        if default_storage.exists(size_path):
-            return settings.MEDIA_URL + size_path
 
-        im = Image.open(self.photo.path)
+        if default_storage.exists(size_path):
+            return default_storage.url(size_path)
+
+        im = Image.open(default_storage.open(self.photo.name))
         im.thumbnail((size, size))
-        
+
         #im.save(size_path)
         thumb_io = BytesIO()
         im.save(thumb_io, im.format)
         default_storage.save(size_path, File(thumb_io))
-        return settings.MEDIA_URL + size_path
+
+        return default_storage.url(size_path)
 
     def get_original_photo_url(self):
         if self.photo:
-            return settings.MEDIA_URL + self.photo.name
+            return default_storage.url(self.photo.name)
 
 
 def get_import_file_path(instance, filename):
