@@ -9,9 +9,9 @@ class ProjectIndex(TendenciBaseSearchIndex, indexes.Indexable):
     slug = indexes.CharField(model_attr='slug')
     project_name = indexes.CharField(model_attr='project_name')
     project_status = indexes.CharField(model_attr='project_status',)
-    location = indexes.CharField(model_attr='location',)
-    city = indexes.CharField(model_attr='city',)
-    state = indexes.CharField(model_attr='state',)
+    location = indexes.CharField(model_attr='location', null=True)
+    city = indexes.CharField(model_attr='city', null=True)
+    state = indexes.CharField(model_attr='state', null=True)
     start_dt = indexes.DateTimeField(model_attr='start_dt', null=True)
     end_dt = indexes.DateTimeField(model_attr='end_dt', null=True)
     website_title = indexes.CharField(model_attr='website_title',)
